Extensions — BCI-Framework documentation

# Extensions

The BCI-Framework extensions consist of a feature that brings to the user the capabilities to develop real-time neurophysiological experiments with remote stimuli delivery and EEG events synchronization and real-time data analysis and visualizations.

# Subpackages

- Data Analysis
- Submodules
  - Utils
- Stimuli Delivery
- Submodules
  - Stimuli Delivery
  - Tornado Handlers
  - Utils
- Visualizations
- Submodules
  - EEG Stream

# Submodules

- Properties